@@ -8,7 +8,7 @@ use warnings;
 use parent qw{ Specio::Exporter };
 
 use Carp;
-use Date::Tolkien::Shire::Data 0.001 qw{
+use Date::Tolkien::Shire::Data qw{
     __holiday_name_to_number
     __month_name_to_number
 };
@@ -18,7 +18,7 @@ use Specio::Library::Builtins;
 use Specio::Library::Numeric;
 use Specio::Library::String;
 
-our $VERSION = '0.907_01';
+our $VERSION = '0.900';
 
 declare(
     DayOfMonth	=>
@@ -36,45 +36,6 @@ declare(
     },
 );
 
-=begin comment
-
-object_isa_type(
-    Duration	=>
-    class	=> 'DateTime::Fiction::JRRTolkien::Shire::Duration',
-#    class	=> 'DateTime::Duration',
-);
-
-=end comment
-
-=cut
-
-# For some reason the above does not compile, though if you specify
-# 'DateTime::Duration' it does. I believe the following to be
-# equivalent, though I am sure it will produce a less-salubrious error
-# message.
-
-declare(
-    Duration	=>
-    parent	=> t( 'Object' ),
-#    inline	=> sub {
-#	$_[0]->parent->inline_check( $_[1] ) .
-#	" && $_[1]->isa( 'DateTime::Fiction::JRRTolkien::Shire::Duration' )";
-#    },
-#   For some reason the above is a problem under 5.8.9. So:
-    where	=> sub { $_[0]->isa(
-	    'DateTime::Fiction::JRRTolkien::Shire::Duration' ) },
-);
-
-enum(
-    EndOfMonthMode	=>
-    values	=> [ qw{ limit preserve wrap } ],
-);
-
-any_can_type(
-    Formatter	=>
-    methods	=> [ qw{ format_datetime } ],
-);
-
 declare(
     HolidayName	=>
     parent	=> t( 'NonEmptySimpleStr' ),
@@ -108,15 +69,12 @@ declare(
     },
 );
 
-union(
-    IntOrUndef	=>
-    of	=> [ map { t( $_ ) } qw{ Int Undef } ],
-);
 
 declare(
-    LocaleObject	=>
-    parent	=> t( 'Object' ),
-    inline	=> sub {
+    'LocaleObject',
+    parent => t('Object'),
+    inline => sub {
+
         # Can't use $_[1] directly because 5.8 gives very weird errors
         my $var = $_[1];
         <<"EOF";
@@ -129,7 +87,7 @@ EOF
 );
 
 union(
-    Locale	=>
+    'Locale',
     of => [ map { t( $_ ) } qw{ NonEmptySimpleStr LocaleObject } ],
 );
 
@@ -179,6 +137,7 @@ declare(
     },
 );
 
+
 object_can_type(
     'TimeZoneObject',
     methods => [
@@ -218,6 +177,11 @@ declare(
     parent	=> t( 'Int' ),
 );
 
+any_can_type(
+    'Formatter',
+    methods => ['format_datetime'],
+);
+
 1;
 
 __END__
@@ -247,9 +211,7 @@ L<DateTime::Fiction::JRRTolkien::Shire|DateTime::Fiction::JRRTolkien::Shire>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Fiction-JRRTolkien-Shire>,
-L<https://github.com/trwyant/perl-DateTime-Fiction-JRRTolkien-Shire/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -257,7 +219,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2017-2022, 2025 by Thomas R. Wyant, III
+Copyright (C) 2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
